@@ -1,21 +1,33 @@
 #!/usr/bin/python
 #
-# Copyright 2006-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
+# @package		hubzero-addrepo
+# @file			gensvnapache.py
+# @author		Nicholas J. Kisseberth <nkissebe@purdue.edu>
+# @copyright	Copyright (c) 2010-2011 Purdue University. All rights reserved.
+# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+#
+# Copyright (c) 2010-2011 Purdue University
 # All rights reserved.
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License, version 2.1 as published by the Free Software Foundation.
+# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
-# This library is distributed in the hope that it will be useful,
+# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+# software: you can redistribute it and/or modify it under the terms of
+# the GNU Lesser General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# HUBzero is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
+# HUBzero is a registered trademark of Purdue University.
+#
+
 # Really quick and dirty port of the perl script of similar name
 # but querying project data from MySQL instead of LDAP.
 # This should get cleaned up an rewritten to use
@@ -44,13 +56,13 @@ docroot = config.get(section, 'DocumentRoot')
 file_read = open(docroot + '/configuration.php',"r")
 contents = file_read.read()
 file_read.close()
-for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*(.+)\s*;", contents):
+for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\'\"\.0-9@]+)\s*;", contents):
   data['joomla'][m.group(1)] = m.group(2).strip(" \'\"\t")
 
 file_read = open(docroot + '/hubconfiguration.php',"r")
 contents = file_read.read()
 file_read.close()
-for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*(.+)\s*;", contents):
+for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*([a-zA-Z-_\\\,\=\!\/\:\'\"\.0-9@]+)\s*;", contents):
   data['hubzero'][m.group(1)] = string.replace(m.group(2).strip(" \'\"\t"),"\\'","'")
 
 mysql_host = data['joomla']['host']
@@ -61,6 +73,14 @@ ldapbase = data['hubzero']['hubLDAPBaseDN']
 ldaphost = data['hubzero']['hubLDAPMasterHost']
 ldapbinduser = data['hubzero']['hubLDAPSearchUserDN']
 ldapbindpass = data['hubzero']['hubLDAPSearchUserPW']
+ldapgroupobjectclass = 'hubGroup'
+try:
+  ldapgroupobjectclass = data['hubzero']['hubLDAPGroupObjectClass']
+except:
+  pass
+
+if (ldapgroupobjectclass != 'posixGroup'):
+  ldapgroupobjectclass = 'hubGroup'
 
 try:
   db = MySQLdb.connect(host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
@@ -74,6 +94,7 @@ if len(sys.argv) != 5 and len(sys.argv) != 6:
 svnroot = sys.argv[1]
 svnurl = sys.argv[2]
 hubdir = sys.argv[3]
+svnauthz = False
 
 if len(sys.argv) == 5:
   type = sys.argv[4]
@@ -133,6 +154,11 @@ for dir in dirlist:
       #if (len(gid) == 0):
       #	  print name + " has no groups"
 
+    if (os.path.isfile(svnroot + "/" + id + "/conf/svnauthz.conf")):
+      svnauthz = True
+    else:
+      svnauthz = False
+
     url = string.replace(svnurl, "@PROJECT@", id)
 
     print "<Location " + url + ">"
@@ -142,22 +168,37 @@ for dir in dirlist:
     print "\tAuthBasicProvider ldap"
     print "\tAuthName \"" + name + " Subversion Repository\""
     print "\tAuthzLDAPAuthoritative on"
-    if ldapbinduser != "":
+    if (ldapbinduser != ""):
       print "\tAuthLDAPBindDN \"" + ldapbinduser + "\""
-    if ldapbindpass != "":
       print "\tAuthLDAPBindPassword \"" + ldapbindpass + "\""
-    print "\tAuthLDAPGroupAttributeIsDN on"
-    print "\tAuthLDAPGroupAttribute owner"
-    print "\tAuthLDAPGroupAttribute member"
+    if (ldapgroupobjectclass == 'hubGroup'):
+      print "\tAuthLDAPGroupAttributeIsDN on"
+      print "\tAuthLDAPGroupAttribute owner"
+      print "\tAuthLDAPGroupAttribute member"
+    else:
+      print "\tAuthLDAPGroupAttributeIsDN off"
+      print "\tAuthLDAPGroupAttribute memberUid"
+
     print "\tAuthLDAPURL " + ldaphost + "/ou=users," + ldapbase 
-    if sourcepublic:
-      print "\t<LimitExcept GET PROPFIND OPTIONS REPORT>"
-    for group in gid:
+
+    if svnauthz:
+      print "\tAuthzSVNAccessFile " + svnroot + "/" + id + "/conf/svnauthz.conf"
+      print "\tRequire valid-user"
       if sourcepublic:
-        print "\t",
-      print "\tRequire ldap-group gid=" + group  + ",ou=groups," + ldapbase
-    if sourcepublic:
-      print "\t</LimitExcept>"
+        print "\tSatisfy Any"
+    else:
+      if sourcepublic:
+        print "\t<LimitExcept GET PROPFIND OPTIONS REPORT>"
+      for group in gid:
+        if sourcepublic:
+          print "\t",
+        if (ldapgroupobjectclass == 'hubGroup'):
+          print "\tRequire ldap-group gid=" + group  + ",ou=groups," + ldapbase
+        else:
+          print "\tRequire ldap-group cn=" + group  + ",ou=groups," + ldapbase
+      if sourcepublic:
+        print "\t</LimitExcept>"
+
     print "</Location>"
     print ""
  
